@@ -8,7 +8,7 @@ use warnings;
 
 use Carp;
 
-our $VERSION = 0.01; 
+our $VERSION = 0.02; 
 
 require XSLoader;
 XSLoader::load( __PACKAGE__, $VERSION );
@@ -24,8 +24,12 @@ sub import {
 	$^H{"Syntax::Keyword::Combine::Keys/ckeys"}++ if delete $syms{ckeys};
 	   
 	croak "Unrecognised import symbols @{[ keys %syms ]}" if keys %syms;
+
+	1;
 }
 
+1;
+
 =head1 NAME
 
 Syntax::Keyword::Combine::Keys - The great new Syntax::Keyword::Combine::Keys!
@@ -44,9 +48,12 @@ Perhaps a little code snippet.
 
 	use Syntax::Keyword::Combine::Keys;
 
-	for ( ckeys(%{$hash1}, %hash2, e => 'f') ) {
- 		 .... magic ---
-	}
+	my $hash1 = { ... };
+	my %hash2 = ( ... );
+
+	my @keys = ckeys { 
+		uc $_;
+	} (%{$hash1}, %hash2, e => 'f');
 
 =head1 AUTHOR
 
